@@ -1,5 +1,5 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.011';
+$Anki::Import::VERSION = '0.012';
 use strict;
 use warnings;
 use Cwd;
@@ -11,14 +11,15 @@ use Data::Dumper qw(Dumper);
 our @EXPORT = qw(anki_import);
 
 # set up variables
-my @lines;
+my @lines;                # lines from source file
+my $line_count = 0;       # count processed lines to give more helpful error msg
+my $cline      = '';      # current line getting processed
+my $lline      = '';      # last (previous) line processed
 my $ntype      = 'Basic'; # default note type
-my $line_count = 0;       # count lines to give more helpful error msg
-my $cline      = '';      # current line
-my $lline;                # last (previous) line
 my %notes      = ();      # data structure for storing notes
+my @autotags   = ();      # for storing automated tags
 
-# process arguments
+# argument processing
 arg parent_dir => (
   isa => 'Str',
   default => cwd,
@@ -189,19 +190,29 @@ sub generate_importable_files {
   }
 }
 
-# process individual notes
 sub process_note {
   my $note = shift;
 
+  my $new_autotags = 0;
   my $out = '';
   # loop over fields
   foreach my $field (@$note) {
     my $in_code = 0;   # tracks if we are preserving whitespace
     my $field_out = '';
+    my $last_field = '';
 
     # loop over lines in field
     foreach my $line (@$field) {
+
+      # detect automated tags
       logd($line);
+      if ($line =~ /^\^\s*$/) {
+        $field_out =~ s/\s*$//;
+        @autotags = split (/,\s*/, $field_out);
+        $new_autotags = 1;
+        next;
+      }
+
       if ($line =~ /^`\s*$/ && !$in_code) {
         next;
       }
@@ -230,7 +241,6 @@ sub process_note {
         $field_out .= "$line ";
       }
     }
-
     # handle formatting codes in text, preserve escaped characters
 
     # backticked characters
@@ -251,9 +261,32 @@ sub process_note {
 
   # clean up extraneous characters at the end of the line
   $out =~ s/ *\t$|\t$|(<br>)+\t$//;
+
+  # handle autotagging
+  if (@autotags && !$new_autotags) {
+    $note->[-1][0] = '' if $note->[-1][0] =~ /^`\s*$/;
+    my @note_tags = split (/,\s*/, $note->[-1][0]);
+    logd(\@note_tags);
+    my @new_tags = ();
+    foreach my $note_tag (@note_tags) {
+      my $in_autotags = grep { $_ eq $note_tag } @autotags;
+      push @new_tags, $note_tag unless $in_autotags;
+    }
+    foreach my $autotag (@autotags) {
+      my $discard_autotag = grep { $_ eq $autotag } @note_tags;
+      push @new_tags, $autotag if !$discard_autotag;
+    }
+    my @fields = split (/\t/, $out);
+    pop @fields if @note_tags;
+    push @fields, join (',', @new_tags);
+    $out = join "\t", @fields;
+  }
+  $new_autotags = 0;
+
   $out .= "\n";
 }
 
+
 1; # Magic true value
 # ABSTRACT: Anki note generation made easy.
 
@@ -267,7 +300,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 OVERVIEW
 
@@ -298,6 +331,9 @@ Inputting notes into Anki can be a tedious chore. C<Anki::Import> lets you
 you generate Anki notes with your favorite text editor (e.g. vim, BBEdit, Atom,
 etc.) so you can enter formatted notes into Anki's database more efficiently.
 
+At a minimum, you should have basic familiarity with using your computer's
+command line terminal to make use of this program.
+
 =head2 Steps for creating, processing and imorting new notes
 
 =head3 Step 1: Generate the notes with your text editor
@@ -313,7 +349,7 @@ See the L</General description of the source file> section for details.
 Once the source file is created and saved, run the
 C<anki_import> command from the command line or from a script to generate the
 import files. This will create a new directory called "anki_import_files"
-which contains one file for each of the note types generated by C<Anki::Import>
+containing one text file for each of the note types generated by C<Anki::Import>
 and which you will import in the next step. By default, the directory is
 created in the current directory.
 
@@ -379,6 +415,29 @@ note has the correct number of fields.
 Note: note type sections can be split across the file (i.e. you do not have to
 group the notes of a particular note type together).
 
+=head3 Tagging notes
+
+Place your comma seprated lit of tags in the last field. As long as there is
+one more field in the source files that fields in the note you are importing
+to, Anki will generate tags from the last field.
+
+You can automate tag generation by placing a single '^' (caret) character
+on a line by itself immediately after your list of tags. These tags will now
+be used for all later notes in the file until they are overridden by a new list
+of automated tags. Also any new tags you place at the end of a note will be
+added to the list of tags that are automatically generated.
+
+To reset the automated list of tags, place a single '^' (caret) character
+in place of the field where your tags will go.
+
+To suppress the application of an automated tag from the list of automated tags
+for a particular note, include that tag in the tag field and it will not be
+tagged with that term for that one note.
+
+Note: If you use tags on any of your notes in a parcitular note type, you must
+use tags on all of your notes or indicate that the tag field should be left
+blank with a '`' (backtick) character on a line by itself.
+
 =head3 Applying text formatting to your notes
 
 Learning how to format the source file is key to getting Anki to import your
@@ -424,7 +483,6 @@ source data file.
 
 
 
-
     # less_basic                         # New note type called "less_basic"
                                          # with 3 fields
     What is the third day of week?       # Question 3, Field 1
@@ -433,13 +491,21 @@ source data file.
 
     Wed.                                 # Question 3, Field 3
 
+    your_tags, go_here                   # We set up automated tags on this note.
+    ^                                    # These tags will be applied to this and
+                                         # all future notes unless overridden.
+
 
     Put another question here.
 
     Here is an answer that has
     `                                    # Insert a blank line into a field
     a blank line in it.                  # with a single backtick character
-                                         # surround by lines with text
+                                         # surrounded by lines with text.
+    go_here                              # The note will *not* be tagged with
+                                         # 'go_here' but it will still be
+                                         # tagged with 'your_tags' from
+                                         # the automated tag list.
 
 
 
@@ -453,20 +519,23 @@ source data file.
     }
     ```                                  # end whitespace preservation
 
-    Answer goes here.
+    This is %comma,delimted,text%        # Bullet lists with %item1,item2,item3%
 
+    '                                    # To suppress all tags for a note,
+                                         # leave the tag field blank with a
+                                         # backtick.
 
 
     Final question                       # Field 1
 
-    `                                    # Field 2 is blank. Use single backtick
-                                         # on a line surrouned by blank lines.
-    This is *in bold*                    # Field 3 has bold words
-    `                                    # and a blank line
-    This is %an,unordered,list%          # and uses percent sign with comma
-                                         # delimited text to generate an
-                                         # unordered HTML list, with one item for
-                                         # each term separated with commas
+    `                                    # Field 2 is blank.
+
+    This is *in bold*                    # Field 3 has bold words, followed by a
+    `                                    # blank line, followed by
+    %an,unordered,list%                  # an ordered list.
+
+    new_tags, more_new_tags              # This and future notes will use these
+    ^                                    # newer automated tags.
 
 =head1 USAGE
 
@@ -475,20 +544,24 @@ script. It behaves the same way in both environments.
 
 =head2 Command line usage
 
-C<Anki::Import> provides a command for generating import files:
+The C<Anki::Import> module installs the C<anki_import> command line command
+for generating import files which is used as follow:
 
     anki_import source_file [parent_dir] [verbosity_level]
 
-The command processes the source file and generates files to be imported into
+    B<Example:> anki_import notes.text /home/me --verbose
+
+C<anki_import> processes the source file and generates files to be imported into
 Anki, one file for each note type. These files are placed in a directory called
 C<anki_import_files>. This directory is placed in the current working directory
 by default.
 
-Note: All previously generated files of a particular note type will be
+Note: Previously generated files of a particular note type will be
 overwritten by this command without warning.
 
 B<C<parent_dir>> is an optional argument containing the path you want C<Anki::Import>
-to save the files for output.
+to save the files for output. You may use C<~> (tilde) to represent the home
+directory for the current user.
 
 B<C<$verbosity>> can be set to either C<--verbose> (C<-v>) or C<--vverbose> (C<-vv>)
 for verbosity and maximum verbosity, respectively.
@@ -500,6 +573,13 @@ command line:
 
 =head2 anki_import($source_file, [$parent_dir], [$verbosity]);
 
+Usage in a script is the same as for the command line except that the arguments
+must be enclosed in quotes.
+
+    Example:
+
+    anki_import('script_file.txt', '/home/me', '--verbose');
+
 See the L</Command line usage> for more details on the optional arguments.
 
 =head1 REQUIRES
